/**
* Game Javascript API and platform specific handlers
*/
function get_gameApi()
{
	return gameApi;
}

function getInternetExplorerVersion() {

    var rv = -1; // Return value assumes failure.

    if (navigator.appName == 'Microsoft Internet Explorer') {

        var ua = navigator.userAgent;

        var re = new RegExp("MSIE ([0-9]{1,}[\.0-9]{0,})");

        if (re.exec(ua) != null)

            rv = parseFloat(RegExp.$1);
    }

    return rv;
}

jQuery.browser = {};
jQuery.browser.mozilla = /mozilla/.test(navigator.userAgent.toLowerCase()) && !/webkit/.test(navigator.userAgent.toLowerCase());
jQuery.browser.webkit = /webkit/.test(navigator.userAgent.toLowerCase());
jQuery.browser.opera = /opera/.test(navigator.userAgent.toLowerCase());
jQuery.browser.msie = /msie/.test(navigator.userAgent.toLowerCase());

function isMozilla()
{
	return jQuery.browser.mozilla;
}

var gameApi =
{	
	/// :::::::::::::: AUDIO ::::::::::::::
	
	music: [
			{name:"music_game",src:"assets/audio_mobile/music_game.mp3", type:"audio/mp3"}
		],

	// String name for the current playing music
	currentMusicName:null,
	
	// HTML Audio element
	currentMusic:null,	
	
	isMuted:false,	
	
	/// :::::::::::::::::::::::::::::::::::
	
	onOrientationChange:null,
	
	ipadVersion:0,

	gameSize: {
		width:448,
		height:672
	},
	
	gameResizeFunc:null,
	
	isFirstOrientationCheck:true,
	isReversedOrientation:false,
	
	init:function()
	{		
		//Set the right orientation pop-up image
		if(navigator.userAgent.match(/iPhone|iPod|Android/i))
		{
			document.getElementById("imgPortraitWarning").src = "assets/popup_landscape/orientation_iphone.png";
		}
	},
  
	/* Portrait mode warning, called from com.bkom.core.views.AbstractViewManager.update() */
	showPortraitWarning:function(isReversed)
	{		
		if (isReversed)
		{
			document.getElementById('portrait').style.cssText="display: block; z-index:10000;width:"+window.innerWidth+"px;height:"+window.innerHeight+"px;";
			//calculate the scale
			var scale = Math.min(window.innerWidth/350, window.innerHeight/337, 1);
			document.getElementById('imgPortraitWarning').style.cssText="-webkit-transform: rotate(90deg) scale("+scale+"); transform: rotate(90deg); scale("+scale+");";
		}else{
			document.getElementById('portrait').style.cssText="display: block; z-index:10000;width:"+window.innerWidth+"px;height:"+window.innerHeight+"px;";
			//calculate the scale
			var scale = Math.min(350/window.innerWidth, 337/window.innerHeight);
			document.getElementById('imgPortraitWarning').style.cssText="-webkit-transform: translate(-100px,0px) rotate(180deg) scale("+scale+"); transform: translate(-100px,0px) rotate(180deg); scale("+scale+");";
		}
	},
	
	hidePortraitWarning:function()
	{
		document.getElementById('portrait').style.cssText="display:none;z-index:-1;";		
	},
	
	
	/// :::::::::::::::::::::::::::::::::::
	/// :::::::::::::: AUDIO ::::::::::::::
	/// :::::::::::::::::::::::::::::::::::
	
	addAudio:function(options)
	{
		var ctx = this;
		var audio = document.createElement('audio');
		audio.setAttribute('id', options.name);
		audio.setAttribute('autobuffer', "autobuffer");
		audio.setAttribute('preload', "auto");
		audio.setAttribute('style', "display: none");
		if (ctx.onLevelMusicLoaded)
		{
			audio.addEventListener('canplaythrough', function(){ctx.onLevelMusicLoaded(); ctx.onLevelMusicLoaded = null;});
			//audio.addEventListener('canplay', ctx.onLevelMusicLoaded);
		}		
		
		var audioSource = document.createElement('source');
		audio.setAttribute('src', options.src);
		audio.setAttribute('type', options.type);		
		
		audio.style.cssText = "display: none !important";
		
		audio.appendChild(audioSource);
		
		document.body.appendChild(audio);
		
		return audio;
	},

	removeAudio:function()
	{
		if (this.currentMusic) this.currentMusic.pause();
		this.currentMusic = null;
		if (document.getElementById('audio'))
		{
			domRemove('audio');
		}
	},
	
	playMusic:function(musicName, loop, volume, ignoreSameMusic)
	{	
		if(!ignoreSameMusic && this.currentMusicName==musicName) return;

		this.removeAudio();

		for (var i = 0; i < this.music.length; i++)
		{
			if (this.music[i].name == musicName)
			{
				this.currentMusic = this.addAudio( this.music[i] );
				break;
			}
		}
		
		if(this.currentMusic!=null)
		{
			this.currentMusicName = musicName;
			
			if (loop == true){
				this.currentMusic.setAttribute('loop', "loop");
			}else if (this.currentMusic.getAttribute('loop'))
			{
				this.currentMusic.removeAttribute('loop');
			}
			
			if (this.currentMusic.currentTime>0)
			{
				this.currentMusic.currentTime = 0;
			}                       
			if(volume>0) this.currentMusic.volume = volume;
			if(!this.isMuted) this.currentMusic.play();
		}
	},	
	
	mute:function()
	{
		if(this.currentMusic!=null)
		{
			this.currentMusic.pause();
		}
		this.isMuted = true;
	},
	
	unmute:function()
	{
		if(this.currentMusic!=null)
		{
			this.currentMusic.play();
		}
		this.isMuted = false;
	},
	
	pause:function()
	{
		this.mute()
	},
	
	resume:function()
	{
		this.unmute()
	},
	
	/// :::::::::::::::::::::::::::::::::::
	/// ::::::::::: AUDIO END :::::::::::::
	/// :::::::::::::::::::::::::::::::::::
	
	
	// http://javascript.crockford.com/memory/leak.html
	// cleans dom element to prevent memory leaks
	domPurge:function(d) 
	{
	    var a = d.attributes, i, l, n;
	    if (a) {
	        for (i = a.length - 1; i >= 0; i -= 1) {
	            n = a[i].name;
	            if (typeof d[n] === 'function') {
	                d[n] = null;
	            }
	        }
	    }
	    a = d.childNodes;
	    if (a) {
	        l = a.length;
	        for (i = 0; i < l; i += 1) {
	            domPurge(d.childNodes[i]);
	       }
	    }
	},

	domRemove:function(id) 
	{
	    var elem = document.getElementById(id);
	    domPurge(elem);
	    return elem.parentNode.removeChild(elem);
	},
	
	isIos5:function()
	{
		if(/OS [5]_\d(_\d)? like Mac OS X/i.test(navigator.userAgent)) 
		{			
			return true;
		}
		else
		{
			return false;
		}
	},	
	
	// Open a page in a new window
	openPage:function(url)
	{		
		var win=window.open(url,"_blank");
		if (win)
		{
			win.focus();
		}
	},
	
	// Get by the game if this one can start normally
	canStartGame:function()
	{
		return window.gameReady;
	}
	
};

var isFixed = false;
var firstOrientationCheckDone = false;
var firstOrientation = "";

function onOrientationChange(event)
{
	if (!isFixed && !firstOrientationCheckDone)
	{
		firstOrientation = event.orientation;
		firstOrientationCheckDone = true;
	}
	
	if (navigator.userAgent.match(/iPhone|iPod|Android/i)) 
	{		
		if (event.orientation == "landscape")
		{
			callOnOrientationChange(event.orientation, false);
			gameApi.showPortraitWarning(true);
		}else{
			callOnOrientationChange(event.orientation, true);
			gameApi.hidePortraitWarning();
		}
	}else if (navigator.userAgent.match(/iPad/i))
	{
		if (event.orientation == "portrait")
		{
			callOnOrientationChange(event.orientation, false);
			gameApi.showPortraitWarning(false);
		}else{
			callOnOrientationChange(event.orientation, true);
			gameApi.hidePortraitWarning();
		}				
	}	
}

var callOnOrientationChange = function(foo,bar){};
function bindToOrientationChange(func)
{
	callOnOrientationChange = func;
}

gameApi.init();