var flambeCanvas = document.getElementById("content-canvas");

/**
 * Get Audio Manager functions (call from Gamecore)
 * 
 */
function get_audioManager()
{
	return audioEngine;
}

/**
 * All Audio Manager functions
 * 
 */
var audioEngine =
{
	playSound:function(name,interrupt,delay,offset,loop,volume,pan)
	{
		return createjs.Sound.play(name,interrupt,delay,offset,loop,volume,pan);
	},
	
	setMasterVolume:function(value)
	{
		createjs.Sound.setVolume(value);
	},
	
	checkReady:function()
	{
		return createjs.Sound.isReady();
	},
	
	checkIfSndLoaded:function(snd)
	{
		return createjs.Sound.loadComplete(snd);
	}
}

var funcToCallOnLoad = null;

/**
 * Audio Manager
 * 
 */
function audioManager() 
{
	var context = this;
	var eventType = "";
	var nbSoundsToLoad = 0;
	var nbSoundsLoaded = 0;
	
	/**
	 * Init
	 * 
	 */
	function init()
	{		
		var mobile = navigator.userAgent.match(/iPhone|iPad|iPod/i) || navigator.userAgent.match(/Android/i) || (navigator.userAgent.indexOf("Silk") !== -1);
		
		if (!mobile)
		{
			// Web
			handleClick();			
		}
		else
		{
			// Mobile
			eventType = "touchstart";
			// Register event for initialization
			flambeCanvas.addEventListener(eventType, handleClick, false);
		}		
	}

	/**
	 * Click event
	 * 
	 */
	function handleClick()
	{
		// Remove event
		if (eventType != "") flambeCanvas.removeEventListener(eventType, handleClick, false);
		
		// Init audio
		if (!createjs.Sound.isReady())
		{			
			// Init engine
			if (!createjs.Sound.initializeDefaultPlugins()) {				
				funcToCallOnLoad();
				return;
			}
			
			// Init all sound
			var audioPath = "assets-html/audio/";
			var manifest = [
				{id:"music_game", src: { ogg:"music_game.ogg", mp3:"music_game.mp3"}},
                {id:"music_menu", src: {ogg:"music_menu.ogg", mp3:"music_menu.mp3" }} ,
				{id:"sfx_match", src:{ ogg:"sfx_match.ogg", mp3:"sfx_match.mp3"}},
				{id:"sfx_tileSelect", src:{ ogg:"sfx_tileSelect.ogg", mp3:"sfx_tileSelect.mp3"}},
				{id:"sfx_noMatch", src: {ogg:"sfx_noMatch.ogg", mp3:"sfx_noMatch.mp3"}},
				{id:"sfx_customerSBM", src: {ogg:"sfx_customerSBM.ogg", mp3:"sfx_customerSBM.mp3"}},
				{id:"sfx_customerLastRow", src: { ogg:"sfx_customerLastRow.ogg" , mp3:"sfx_customerLastRow.mp3"}},
				{id:"sfx_customerReachGrid", src: { ogg:"sfx_customerReachGrid.ogg", mp3:"sfx_customerReachGrid.mp3"}},
				{id:"sfx_powerUp", src: { ogg:"sfx_powerUp.ogg", mp3:"sfx_powerUp.mp3"}},
				{id:"sfx_click", src: { ogg:"sfx_click.ogg", mp3:"sfx_click.mp3"}},
				{id:"sfx_customerApplause", src: { ogg:"sfx_customerApplause.ogg", mp3:"sfx_customerApplause.mp3"}},
				{id:"sfx_10secLeft", src: { ogg:"sfx_10secLeft.ogg", mp3:"sfx_10secLeft.mp3"}},
				{id:"sfx_itemToCustomer", src: { ogg:"sfx_itemToCustomer.ogg", mp3:"sfx_itemToCustomer.mp3"}}
			];                  
					
			nbSoundsToLoad = manifest.length;
			createjs.Sound.addEventListener("fileload", handleLoad);
			createjs.Sound.registerSounds(manifest, audioPath);
		}else{
			funcToCallOnLoad();
		}
	}

	/**
	 * Load end event
	 * 
	 * @param	event
	 */
	function handleLoad(event)
	{		
		nbSoundsLoaded++;
		if (nbSoundsLoaded >= nbSoundsToLoad)
		{		
			funcToCallOnLoad();			
		}
	}
	
	function onSoundsLoaded(funcToCall)
	{
		funcToCallOnLoad = funcToCall;
	}

	//Public methods
	this.init = init;
	this.onSoundsLoaded = onSoundsLoaded;
	
	return this;
}

function onSoundsLoaded(funcToCall)
{
	audioManager().onSoundsLoaded(funcToCall);
}